@@ -2,6 +2,7 @@ from ccxt.base.types import Entry
 
 
 class ImplicitAPI:
+    public_spot_get_notice_queryallnotices = publicSpotGetNoticeQueryAllNotices = Entry('notice/queryAllNotices', ['public', 'spot'], 'GET', {'cost': 1})
     public_spot_get_public_time = publicSpotGetPublicTime = Entry('public/time', ['public', 'spot'], 'GET', {'cost': 1})
     public_spot_get_public_currencies = publicSpotGetPublicCurrencies = Entry('public/currencies', ['public', 'spot'], 'GET', {'cost': 6.6667})
     public_spot_get_public_products = publicSpotGetPublicProducts = Entry('public/products', ['public', 'spot'], 'GET', {'cost': 1})
@@ -13,6 +14,7 @@ class ImplicitAPI:
     public_spot_get_market_candles = publicSpotGetMarketCandles = Entry('market/candles', ['public', 'spot'], 'GET', {'cost': 1})
     public_spot_get_market_depth = publicSpotGetMarketDepth = Entry('market/depth', ['public', 'spot'], 'GET', {'cost': 1})
     public_spot_get_market_spot_vip_level = publicSpotGetMarketSpotVipLevel = Entry('market/spot-vip-level', ['public', 'spot'], 'GET', {'cost': 2})
+    public_spot_get_market_history_candles = publicSpotGetMarketHistoryCandles = Entry('market/history-candles', ['public', 'spot'], 'GET', {'cost': 1})
     public_mix_get_market_contracts = publicMixGetMarketContracts = Entry('market/contracts', ['public', 'mix'], 'GET', {'cost': 1})
     public_mix_get_market_depth = publicMixGetMarketDepth = Entry('market/depth', ['public', 'mix'], 'GET', {'cost': 1})
     public_mix_get_market_ticker = publicMixGetMarketTicker = Entry('market/ticker', ['public', 'mix'], 'GET', {'cost': 1})
@@ -29,19 +31,24 @@ class ImplicitAPI:
     public_mix_get_market_mark_price = publicMixGetMarketMarkPrice = Entry('market/mark-price', ['public', 'mix'], 'GET', {'cost': 1})
     public_mix_get_market_symbol_leverage = publicMixGetMarketSymbolLeverage = Entry('market/symbol-leverage', ['public', 'mix'], 'GET', {'cost': 1})
     public_mix_get_market_querypositionlever = publicMixGetMarketQueryPositionLever = Entry('market/queryPositionLever', ['public', 'mix'], 'GET', {'cost': 1})
+    public_mix_get_market_open_limit = publicMixGetMarketOpenLimit = Entry('market/open-limit', ['public', 'mix'], 'GET', {'cost': 1})
+    public_mix_get_market_history_candles = publicMixGetMarketHistoryCandles = Entry('market/history-candles', ['public', 'mix'], 'GET', {'cost': 1})
+    public_mix_get_market_history_index_candles = publicMixGetMarketHistoryIndexCandles = Entry('market/history-index-candles', ['public', 'mix'], 'GET', {'cost': 1})
+    public_mix_get_market_history_mark_candles = publicMixGetMarketHistoryMarkCandles = Entry('market/history-mark-candles', ['public', 'mix'], 'GET', {'cost': 1})
     public_margin_get_cross_public_interestrateandlimit = publicMarginGetCrossPublicInterestRateAndLimit = Entry('cross/public/interestRateAndLimit', ['public', 'margin'], 'GET', {'cost': 2})
     public_margin_get_isolated_public_interestrateandlimit = publicMarginGetIsolatedPublicInterestRateAndLimit = Entry('isolated/public/interestRateAndLimit', ['public', 'margin'], 'GET', {'cost': 2})
     public_margin_get_cross_public_tierdata = publicMarginGetCrossPublicTierData = Entry('cross/public/tierData', ['public', 'margin'], 'GET', {'cost': 2})
     public_margin_get_isolated_public_tierdata = publicMarginGetIsolatedPublicTierData = Entry('isolated/public/tierData', ['public', 'margin'], 'GET', {'cost': 2})
     public_margin_get_public_currencies = publicMarginGetPublicCurrencies = Entry('public/currencies', ['public', 'margin'], 'GET', {'cost': 1})
-    public_margin_get_cross_account_assets = publicMarginGetCrossAccountAssets = Entry('cross/account/assets', ['public', 'margin'], 'GET', {'cost': 2})
-    public_margin_get_isolated_account_assets = publicMarginGetIsolatedAccountAssets = Entry('isolated/account/assets', ['public', 'margin'], 'GET', {'cost': 2})
     private_spot_get_wallet_deposit_address = privateSpotGetWalletDepositAddress = Entry('wallet/deposit-address', ['private', 'spot'], 'GET', {'cost': 4})
     private_spot_get_wallet_withdrawal_list = privateSpotGetWalletWithdrawalList = Entry('wallet/withdrawal-list', ['private', 'spot'], 'GET', {'cost': 1})
     private_spot_get_wallet_deposit_list = privateSpotGetWalletDepositList = Entry('wallet/deposit-list', ['private', 'spot'], 'GET', {'cost': 1})
     private_spot_get_account_getinfo = privateSpotGetAccountGetInfo = Entry('account/getInfo', ['private', 'spot'], 'GET', {'cost': 20})
     private_spot_get_account_assets = privateSpotGetAccountAssets = Entry('account/assets', ['private', 'spot'], 'GET', {'cost': 2})
+    private_spot_get_account_assets_lite = privateSpotGetAccountAssetsLite = Entry('account/assets-lite', ['private', 'spot'], 'GET', {'cost': 2})
     private_spot_get_account_transferrecords = privateSpotGetAccountTransferRecords = Entry('account/transferRecords', ['private', 'spot'], 'GET', {'cost': 1})
+    private_spot_get_convert_currencies = privateSpotGetConvertCurrencies = Entry('convert/currencies', ['private', 'spot'], 'GET', {'cost': 2})
+    private_spot_get_convert_convert_record = privateSpotGetConvertConvertRecord = Entry('convert/convert-record', ['private', 'spot'], 'GET', {'cost': 2})
     private_spot_post_wallet_transfer = privateSpotPostWalletTransfer = Entry('wallet/transfer', ['private', 'spot'], 'POST', {'cost': 4})
     private_spot_post_wallet_transfer_v2 = privateSpotPostWalletTransferV2 = Entry('wallet/transfer-v2', ['private', 'spot'], 'POST', {'cost': 4})
     private_spot_post_wallet_subtransfer = privateSpotPostWalletSubTransfer = Entry('wallet/subTransfer', ['private', 'spot'], 'POST', {'cost': 10})
@@ -68,6 +75,8 @@ class ImplicitAPI:
     private_spot_post_plan_currentplan = privateSpotPostPlanCurrentPlan = Entry('plan/currentPlan', ['private', 'spot'], 'POST', {'cost': 1})
     private_spot_post_plan_historyplan = privateSpotPostPlanHistoryPlan = Entry('plan/historyPlan', ['private', 'spot'], 'POST', {'cost': 1})
     private_spot_post_plan_batchcancelplan = privateSpotPostPlanBatchCancelPlan = Entry('plan/batchCancelPlan', ['private', 'spot'], 'POST', {'cost': 2})
+    private_spot_post_convert_quoted_price = privateSpotPostConvertQuotedPrice = Entry('convert/quoted-price', ['private', 'spot'], 'POST', {'cost': 4})
+    private_spot_post_convert_trade = privateSpotPostConvertTrade = Entry('convert/trade', ['private', 'spot'], 'POST', {'cost': 4})
     private_spot_post_trace_order_ordercurrentlist = privateSpotPostTraceOrderOrderCurrentList = Entry('trace/order/orderCurrentList', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_trace_order_orderhistorylist = privateSpotPostTraceOrderOrderHistoryList = Entry('trace/order/orderHistoryList', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_trace_order_closetrackingorder = privateSpotPostTraceOrderCloseTrackingOrder = Entry('trace/order/closeTrackingOrder', ['private', 'spot'], 'POST', {'cost': 2})
@@ -81,6 +90,8 @@ class ImplicitAPI:
     private_spot_post_trace_user_myfollowers = privateSpotPostTraceUserMyFollowers = Entry('trace/user/myFollowers', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_trace_config_setproductcode = privateSpotPostTraceConfigSetProductCode = Entry('trace/config/setProductCode', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_trace_user_removetrader = privateSpotPostTraceUserRemoveTrader = Entry('trace/user/removeTrader', ['private', 'spot'], 'POST', {'cost': 2})
+    private_spot_post_trace_getremovablefollower = privateSpotPostTraceGetRemovableFollower = Entry('trace/getRemovableFollower', ['private', 'spot'], 'POST', {'cost': 2})
+    private_spot_post_trace_user_removefollower = privateSpotPostTraceUserRemoveFollower = Entry('trace/user/removeFollower', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_trace_profit_totalprofitinfo = privateSpotPostTraceProfitTotalProfitInfo = Entry('trace/profit/totalProfitInfo', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_trace_profit_totalprofitlist = privateSpotPostTraceProfitTotalProfitList = Entry('trace/profit/totalProfitList', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_trace_profit_profithislist = privateSpotPostTraceProfitProfitHisList = Entry('trace/profit/profitHisList', ['private', 'spot'], 'POST', {'cost': 2})
@@ -93,6 +104,7 @@ class ImplicitAPI:
     private_mix_get_position_singleposition_v2 = privateMixGetPositionSinglePositionV2 = Entry('position/singlePosition-v2', ['private', 'mix'], 'GET', {'cost': 2})
     private_mix_get_position_allposition = privateMixGetPositionAllPosition = Entry('position/allPosition', ['private', 'mix'], 'GET', {'cost': 4})
     private_mix_get_position_allposition_v2 = privateMixGetPositionAllPositionV2 = Entry('position/allPosition-v2', ['private', 'mix'], 'GET', {'cost': 4})
+    private_mix_get_position_history_position = privateMixGetPositionHistoryPosition = Entry('position/history-position', ['private', 'mix'], 'GET', {'cost': 1})
     private_mix_get_account_accountbill = privateMixGetAccountAccountBill = Entry('account/accountBill', ['private', 'mix'], 'GET', {'cost': 2})
     private_mix_get_account_accountbusinessbill = privateMixGetAccountAccountBusinessBill = Entry('account/accountBusinessBill', ['private', 'mix'], 'GET', {'cost': 4})
     private_mix_get_order_current = privateMixGetOrderCurrent = Entry('order/current', ['private', 'mix'], 'GET', {'cost': 1})
@@ -124,10 +136,10 @@ class ImplicitAPI:
     private_mix_post_account_setmarginmode = privateMixPostAccountSetMarginMode = Entry('account/setMarginMode', ['private', 'mix'], 'POST', {'cost': 4})
     private_mix_post_account_setpositionmode = privateMixPostAccountSetPositionMode = Entry('account/setPositionMode', ['private', 'mix'], 'POST', {'cost': 4})
     private_mix_post_order_placeorder = privateMixPostOrderPlaceOrder = Entry('order/placeOrder', ['private', 'mix'], 'POST', {'cost': 2})
-    private_mix_post_order_modifyorder = privateMixPostOrderModifyOrder = Entry('order/modifyOrder', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_order_batch_orders = privateMixPostOrderBatchOrders = Entry('order/batch-orders', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_order_cancel_order = privateMixPostOrderCancelOrder = Entry('order/cancel-order', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_order_cancel_batch_orders = privateMixPostOrderCancelBatchOrders = Entry('order/cancel-batch-orders', ['private', 'mix'], 'POST', {'cost': 2})
+    private_mix_post_order_modifyorder = privateMixPostOrderModifyOrder = Entry('order/modifyOrder', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_order_cancel_symbol_orders = privateMixPostOrderCancelSymbolOrders = Entry('order/cancel-symbol-orders', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_order_cancel_all_orders = privateMixPostOrderCancelAllOrders = Entry('order/cancel-all-orders', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_order_close_all_positions = privateMixPostOrderCloseAllPositions = Entry('order/close-all-positions', ['private', 'mix'], 'POST', {'cost': 20})
@@ -143,15 +155,29 @@ class ImplicitAPI:
     private_mix_post_plan_cancelallplan = privateMixPostPlanCancelAllPlan = Entry('plan/cancelAllPlan', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_trace_closetrackorder = privateMixPostTraceCloseTrackOrder = Entry('trace/closeTrackOrder', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_trace_modifytpsl = privateMixPostTraceModifyTPSL = Entry('trace/modifyTPSL', ['private', 'mix'], 'POST', {'cost': 2})
+    private_mix_post_trace_closetrackorderbysymbol = privateMixPostTraceCloseTrackOrderBySymbol = Entry('trace/closeTrackOrderBySymbol', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_trace_setupcopysymbols = privateMixPostTraceSetUpCopySymbols = Entry('trace/setUpCopySymbols', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_trace_followersetbatchtraceconfig = privateMixPostTraceFollowerSetBatchTraceConfig = Entry('trace/followerSetBatchTraceConfig', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_trace_followerclosebytrackingno = privateMixPostTraceFollowerCloseByTrackingNo = Entry('trace/followerCloseByTrackingNo', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_trace_followerclosebyall = privateMixPostTraceFollowerCloseByAll = Entry('trace/followerCloseByAll', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_trace_followersettpsl = privateMixPostTraceFollowerSetTpsl = Entry('trace/followerSetTpsl', ['private', 'mix'], 'POST', {'cost': 2})
     private_mix_post_trace_cancelcopytrader = privateMixPostTraceCancelCopyTrader = Entry('trace/cancelCopyTrader', ['private', 'mix'], 'POST', {'cost': 4})
+    private_mix_post_trace_traderupdateconfig = privateMixPostTraceTraderUpdateConfig = Entry('trace/traderUpdateConfig', ['private', 'mix'], 'POST', {'cost': 2})
+    private_mix_post_trace_mytraderlist = privateMixPostTraceMyTraderList = Entry('trace/myTraderList', ['private', 'mix'], 'POST', {'cost': 2})
+    private_mix_post_trace_myfollowerlist = privateMixPostTraceMyFollowerList = Entry('trace/myFollowerList', ['private', 'mix'], 'POST', {'cost': 2})
+    private_mix_post_trace_removefollower = privateMixPostTraceRemoveFollower = Entry('trace/removeFollower', ['private', 'mix'], 'POST', {'cost': 2})
+    private_mix_post_trace_public_getfollowerconfig = privateMixPostTracePublicGetFollowerConfig = Entry('trace/public/getFollowerConfig', ['private', 'mix'], 'POST', {'cost': 2})
+    private_mix_post_trace_report_order_historylist = privateMixPostTraceReportOrderHistoryList = Entry('trace/report/order/historyList', ['private', 'mix'], 'POST', {'cost': 2})
+    private_mix_post_trace_report_order_currentlist = privateMixPostTraceReportOrderCurrentList = Entry('trace/report/order/currentList', ['private', 'mix'], 'POST', {'cost': 2})
+    private_mix_post_trace_querytradertpslratioconfig = privateMixPostTraceQueryTraderTpslRatioConfig = Entry('trace/queryTraderTpslRatioConfig', ['private', 'mix'], 'POST', {'cost': 2})
+    private_mix_post_trace_traderupdatetpslratioconfig = privateMixPostTraceTraderUpdateTpslRatioConfig = Entry('trace/traderUpdateTpslRatioConfig', ['private', 'mix'], 'POST', {'cost': 2})
     private_user_get_fee_query = privateUserGetFeeQuery = Entry('fee/query', ['private', 'user'], 'GET', {'cost': 2})
     private_user_get_sub_virtual_list = privateUserGetSubVirtualList = Entry('sub/virtual-list', ['private', 'user'], 'GET', {'cost': 2})
     private_user_get_sub_virtual_api_list = privateUserGetSubVirtualApiList = Entry('sub/virtual-api-list', ['private', 'user'], 'GET', {'cost': 2})
+    private_user_get_tax_spot_record = privateUserGetTaxSpotRecord = Entry('tax/spot-record', ['private', 'user'], 'GET', {'cost': 1})
+    private_user_get_tax_future_record = privateUserGetTaxFutureRecord = Entry('tax/future-record', ['private', 'user'], 'GET', {'cost': 1})
+    private_user_get_tax_margin_record = privateUserGetTaxMarginRecord = Entry('tax/margin-record', ['private', 'user'], 'GET', {'cost': 1})
+    private_user_get_tax_p2p_record = privateUserGetTaxP2pRecord = Entry('tax/p2p-record', ['private', 'user'], 'GET', {'cost': 1})
     private_user_post_sub_virtual_create = privateUserPostSubVirtualCreate = Entry('sub/virtual-create', ['private', 'user'], 'POST', {'cost': 4})
     private_user_post_sub_virtual_modify = privateUserPostSubVirtualModify = Entry('sub/virtual-modify', ['private', 'user'], 'POST', {'cost': 4})
     private_user_post_sub_virtual_api_batch_create = privateUserPostSubVirtualApiBatchCreate = Entry('sub/virtual-api-batch-create', ['private', 'user'], 'POST', {'cost': 20})
@@ -194,6 +220,8 @@ class ImplicitAPI:
     private_margin_get_cross_interest_list = privateMarginGetCrossInterestList = Entry('cross/interest/list', ['private', 'margin'], 'GET', {'cost': 2})
     private_margin_get_cross_liquidation_list = privateMarginGetCrossLiquidationList = Entry('cross/liquidation/list', ['private', 'margin'], 'GET', {'cost': 2})
     private_margin_get_cross_fin_list = privateMarginGetCrossFinList = Entry('cross/fin/list', ['private', 'margin'], 'GET', {'cost': 2})
+    private_margin_get_cross_account_assets = privateMarginGetCrossAccountAssets = Entry('cross/account/assets', ['private', 'margin'], 'GET', {'cost': 2})
+    private_margin_get_isolated_account_assets = privateMarginGetIsolatedAccountAssets = Entry('isolated/account/assets', ['private', 'margin'], 'GET', {'cost': 2})
     private_margin_post_cross_account_borrow = privateMarginPostCrossAccountBorrow = Entry('cross/account/borrow', ['private', 'margin'], 'POST', {'cost': 2})
     private_margin_post_isolated_account_borrow = privateMarginPostIsolatedAccountBorrow = Entry('isolated/account/borrow', ['private', 'margin'], 'POST', {'cost': 2})
     private_margin_post_cross_account_repay = privateMarginPostCrossAccountRepay = Entry('cross/account/repay', ['private', 'margin'], 'POST', {'cost': 2})
@@ -201,6 +229,10 @@ class ImplicitAPI:
     private_margin_post_isolated_account_riskrate = privateMarginPostIsolatedAccountRiskRate = Entry('isolated/account/riskRate', ['private', 'margin'], 'POST', {'cost': 2})
     private_margin_post_cross_account_maxborrowableamount = privateMarginPostCrossAccountMaxBorrowableAmount = Entry('cross/account/maxBorrowableAmount', ['private', 'margin'], 'POST', {'cost': 2})
     private_margin_post_isolated_account_maxborrowableamount = privateMarginPostIsolatedAccountMaxBorrowableAmount = Entry('isolated/account/maxBorrowableAmount', ['private', 'margin'], 'POST', {'cost': 2})
+    private_margin_post_isolated_account_flashrepay = privateMarginPostIsolatedAccountFlashRepay = Entry('isolated/account/flashRepay', ['private', 'margin'], 'POST', {'cost': 2})
+    private_margin_post_isolated_account_queryflashrepaystatus = privateMarginPostIsolatedAccountQueryFlashRepayStatus = Entry('isolated/account/queryFlashRepayStatus', ['private', 'margin'], 'POST', {'cost': 2})
+    private_margin_post_cross_account_flashrepay = privateMarginPostCrossAccountFlashRepay = Entry('cross/account/flashRepay', ['private', 'margin'], 'POST', {'cost': 2})
+    private_margin_post_cross_account_queryflashrepaystatus = privateMarginPostCrossAccountQueryFlashRepayStatus = Entry('cross/account/queryFlashRepayStatus', ['private', 'margin'], 'POST', {'cost': 2})
     private_margin_post_isolated_order_placeorder = privateMarginPostIsolatedOrderPlaceOrder = Entry('isolated/order/placeOrder', ['private', 'margin'], 'POST', {'cost': 4})
     private_margin_post_isolated_order_batchplaceorder = privateMarginPostIsolatedOrderBatchPlaceOrder = Entry('isolated/order/batchPlaceOrder', ['private', 'margin'], 'POST', {'cost': 4})
     private_margin_post_isolated_order_cancelorder = privateMarginPostIsolatedOrderCancelOrder = Entry('isolated/order/cancelOrder', ['private', 'margin'], 'POST', {'cost': 2})
