@@ -81,6 +81,7 @@ class ImplicitAPI:
     public_get_derivatives_v3_public_recent_trade = publicGetDerivativesV3PublicRecentTrade = Entry('derivatives/v3/public/recent-trade', 'public', 'GET', {'cost': 1})
     public_get_derivatives_v3_public_open_interest = publicGetDerivativesV3PublicOpenInterest = Entry('derivatives/v3/public/open-interest', 'public', 'GET', {'cost': 1})
     public_get_derivatives_v3_public_insurance = publicGetDerivativesV3PublicInsurance = Entry('derivatives/v3/public/insurance', 'public', 'GET', {'cost': 1})
+    public_get_v5_market_time = publicGetV5MarketTime = Entry('v5/market/time', 'public', 'GET', {'cost': 1})
     public_get_v5_market_kline = publicGetV5MarketKline = Entry('v5/market/kline', 'public', 'GET', {'cost': 1})
     public_get_v5_market_mark_price_kline = publicGetV5MarketMarkPriceKline = Entry('v5/market/mark-price-kline', 'public', 'GET', {'cost': 1})
     public_get_v5_market_index_price_kline = publicGetV5MarketIndexPriceKline = Entry('v5/market/index-price-kline', 'public', 'GET', {'cost': 1})
@@ -201,6 +202,7 @@ class ImplicitAPI:
     private_get_user_v3_private_frozen_sub_member = privateGetUserV3PrivateFrozenSubMember = Entry('user/v3/private/frozen-sub-member', 'private', 'GET', {'cost': 10})
     private_get_user_v3_private_query_sub_members = privateGetUserV3PrivateQuerySubMembers = Entry('user/v3/private/query-sub-members', 'private', 'GET', {'cost': 5})
     private_get_user_v3_private_query_api = privateGetUserV3PrivateQueryApi = Entry('user/v3/private/query-api', 'private', 'GET', {'cost': 5})
+    private_get_user_v3_private_get_member_type = privateGetUserV3PrivateGetMemberType = Entry('user/v3/private/get-member-type', 'private', 'GET', {'cost': 1})
     private_get_asset_v3_private_transfer_transfer_coin_list_query = privateGetAssetV3PrivateTransferTransferCoinListQuery = Entry('asset/v3/private/transfer/transfer-coin/list/query', 'private', 'GET', {'cost': 0.84})
     private_get_asset_v3_private_transfer_account_coin_balance_query = privateGetAssetV3PrivateTransferAccountCoinBalanceQuery = Entry('asset/v3/private/transfer/account-coin/balance/query', 'private', 'GET', {'cost': 0.84})
     private_get_asset_v3_private_transfer_account_coins_balance_query = privateGetAssetV3PrivateTransferAccountCoinsBalanceQuery = Entry('asset/v3/private/transfer/account-coins/balance/query', 'private', 'GET', {'cost': 50})
@@ -244,11 +246,21 @@ class ImplicitAPI:
     private_get_v5_asset_transfer_query_account_coins_balance = privateGetV5AssetTransferQueryAccountCoinsBalance = Entry('v5/asset/transfer/query-account-coins-balance', 'private', 'GET', {'cost': 2.5})
     private_get_v5_user_query_sub_members = privateGetV5UserQuerySubMembers = Entry('v5/user/query-sub-members', 'private', 'GET', {'cost': 10})
     private_get_v5_user_query_api = privateGetV5UserQueryApi = Entry('v5/user/query-api', 'private', 'GET', {'cost': 10})
+    private_get_v5_user_get_member_type = privateGetV5UserGetMemberType = Entry('v5/user/get-member-type', 'private', 'GET', {'cost': 1})
+    private_get_v5_user_aff_customer_info = privateGetV5UserAffCustomerInfo = Entry('v5/user/aff-customer-info', 'private', 'GET', {'cost': 10})
+    private_get_v5_customer_info = privateGetV5CustomerInfo = Entry('v5/customer/info', 'private', 'GET', {'cost': 10})
     private_get_v5_spot_cross_margin_trade_loan_info = privateGetV5SpotCrossMarginTradeLoanInfo = Entry('v5/spot-cross-margin-trade/loan-info', 'private', 'GET', {'cost': 1})
     private_get_v5_spot_cross_margin_trade_account = privateGetV5SpotCrossMarginTradeAccount = Entry('v5/spot-cross-margin-trade/account', 'private', 'GET', {'cost': 1})
     private_get_v5_spot_cross_margin_trade_orders = privateGetV5SpotCrossMarginTradeOrders = Entry('v5/spot-cross-margin-trade/orders', 'private', 'GET', {'cost': 1})
     private_get_v5_spot_cross_margin_trade_repay_history = privateGetV5SpotCrossMarginTradeRepayHistory = Entry('v5/spot-cross-margin-trade/repay-history', 'private', 'GET', {'cost': 1})
     private_get_v5_ins_loan_ltv_convert = privateGetV5InsLoanLtvConvert = Entry('v5/ins-loan/ltv-convert', 'private', 'GET', {'cost': 1})
+    private_get_v5_broker_earning_record = privateGetV5BrokerEarningRecord = Entry('v5/broker/earning-record', 'private', 'GET', {'cost': 1})
+    private_get_v5_pre_upgrade_order_history = privateGetV5PreUpgradeOrderHistory = Entry('v5/pre-upgrade/order/history', 'private', 'GET', {'cost': 1})
+    private_get_v5_pre_upgrade_execution_list = privateGetV5PreUpgradeExecutionList = Entry('v5/pre-upgrade/execution/list', 'private', 'GET', {'cost': 1})
+    private_get_v5_pre_upgrade_position_closed_pnl = privateGetV5PreUpgradePositionClosedPnl = Entry('v5/pre-upgrade/position/closed-pnl', 'private', 'GET', {'cost': 1})
+    private_get_v5_pre_upgrade_account_transaction_log = privateGetV5PreUpgradeAccountTransactionLog = Entry('v5/pre-upgrade/account/transaction-log', 'private', 'GET', {'cost': 1})
+    private_get_v5_pre_upgrade_asset_delivery_record = privateGetV5PreUpgradeAssetDeliveryRecord = Entry('v5/pre-upgrade/asset/delivery-record', 'private', 'GET', {'cost': 1})
+    private_get_v5_pre_upgrade_asset_settlement_record = privateGetV5PreUpgradeAssetSettlementRecord = Entry('v5/pre-upgrade/asset/settlement-record', 'private', 'GET', {'cost': 1})
     private_post_v2_private_order_create = privatePostV2PrivateOrderCreate = Entry('v2/private/order/create', 'private', 'POST', {'cost': 30})
     private_post_v2_private_order_cancel = privatePostV2PrivateOrderCancel = Entry('v2/private/order/cancel', 'private', 'POST', {'cost': 30})
     private_post_v2_private_order_cancelall = privatePostV2PrivateOrderCancelAll = Entry('v2/private/order/cancelAll', 'private', 'POST', {'cost': 300})
